@@ -11,6 +11,8 @@ class install:
             filename = "i.txt"
         elif os.path.exists('requirements.txt'):
             filename = "requirements.txt"
+        else:
+            print("Please create requirements.txt or i.txt")
         
         f = open(filename, "a")
         f.write("\n")
